@@ -1,8 +1,7 @@
 /* eslint-disable max-len */
 import {Component, Input, OnInit, OnDestroy, ViewChild, ElementRef} from '@angular/core';
 import {Router, ActivatedRoute} from '@angular/router';
-import {Subject,Observable,of,from} from 'rxjs';
-import {takeUntil,tap,map} from 'rxjs/operators';
+import {Subject,Observable,from,takeUntil} from 'rxjs';
 import {SafeUrl} from '@angular/platform-browser';
 import {IdlService} from '@eg/core/idl.service';
 import {OrgService} from '@eg/core/org.service';
@@ -154,9 +153,6 @@ export class VolCopyTemplateGridComponent implements OnInit, OnDestroy {
                 statcat_filter: templateConfig.statcat_filter?.toString() || '',
                 owning_lib: this.org.get( templateConfig.owning_lib )?.shortname() || '',
                 copy_number: templateConfig.copy_number?.toString() || '',
-                label_class: templateConfig.label_class?.toString() || '',
-                prefix: templateConfig.prefix?.toString() || '',
-                suffix: templateConfig.suffix?.toString() || '',
                 debug: JSON.stringify(templateConfig)
             };
 
@@ -186,24 +182,6 @@ export class VolCopyTemplateGridComponent implements OnInit, OnDestroy {
                 row.floating = group ? group.name() : row.floating;
             }
 
-            if (row.label_class) {
-                const label_class = this.volcopy.commonData.acn_class
-                    .find(p => p.id() === Number(row.label_class));
-                row.label_class = label_class ? label_class.name() : row.label_class;
-            }
-
-            if (row.prefix) {
-                const prefix = this.volcopy.commonData.acn_prefix
-                    .find(p => p.id() === Number(row.prefix));
-                row.prefix = prefix ? prefix.label() : row.prefix;
-            }
-
-            if (row.suffix) {
-                const suffix = this.volcopy.commonData.acn_suffix
-                    .find(p => p.id() === Number(row.suffix));
-                row.suffix = suffix ? suffix.label() : row.suffix;
-            }
-
             if (row.loan_duration) {
                 row.loan_duration = {
                     1: $localize`Short`,
