@@ -1,8 +1,7 @@
 import {DOCUMENT, ViewportScroller} from '@angular/common';
-import {Component, OnInit, ViewChild, HostListener,  inject, NgZone, ElementRef} from '@angular/core';
+import {Component, OnInit, ViewChild, HostListener,  inject} from '@angular/core';
 import {Router, ActivatedRoute, ParamMap} from '@angular/router';
-import {BehaviorSubject, from, Observable, of} from 'rxjs';
-import {catchError, finalize, switchMap, tap, map} from 'rxjs/operators';
+import {BehaviorSubject, from, Observable, of, finalize, switchMap, tap, map} from 'rxjs';
 import {IdlObject, IdlService} from '@eg/core/idl.service';
 import {EventService} from '@eg/core/event.service';
 import {OrgService} from '@eg/core/org.service';
@@ -78,6 +77,13 @@ export class VolCopyComponent implements OnInit {
     changesPendingForStatusBar = false;
     routingAllowed = false;
 
+    // For every org we are editing copies for, whether they require parts to be on copies if the record has parts
+    orgRequiresParts : {[key: number]: boolean} = {};
+
+    // For every copy in the context, whether or not the copy needs to require a part
+    itemRequirePartsMap : {[key: number]: boolean} = {};
+    missingPartsCount = 0;
+
     not_allowed_vols = [];
 
     @ViewChild('pendingChangesDialog', {static: false})
@@ -291,6 +297,18 @@ export class VolCopyComponent implements OnInit {
                 this.context.volNodes().map(n => n.target)))
             .then(_ => this.context.sortHoldings())
             .then(_ => this.context.setRecordId())
+            .then(_ => this.volcopy.fetchBibParts(this.context.getRecordIds()))
+            .then(_ => {
+                // Check for each org if a part is required
+                const orgSettingFetches = [];
+                for (const orgId of this.context.getOwningLibIds()) {
+                    orgSettingFetches.push(this.org.settings('circ.holds.ui_require_monographic_part_when_present', orgId)
+                        .then(settings => {
+                            this.orgRequiresParts[orgId] = Boolean(settings['circ.holds.ui_require_monographic_part_when_present']);
+                        }));
+                }
+                return Promise.all(orgSettingFetches);
+            })
             .then(_ => {
             // unified display has no 'attrs' tab
                 if (this.volcopy.defaults.values.unified_display
@@ -686,7 +704,7 @@ export class VolCopyComponent implements OnInit {
                 // return this.saveApi(volumes, true, close);
                 this.loading = false;
                 alert(evt);
-                return Promise.reject();
+                return Promise.reject(evt);
             }
 
             this.broadcastChanges(volumes);
@@ -731,6 +749,7 @@ export class VolCopyComponent implements OnInit {
         if (!this.volsCanSave) { return true; }
         if (!this.attrsCanSave) { return true; }
         if (this.barcodeNeeded()) { return true; }
+        if (this.partNeeded()) { return true; }
 
         // This can happen regardless of whether we are modifying
         // volumes vs. copies.
@@ -790,6 +809,54 @@ export class VolCopyComponent implements OnInit {
         return result;
     }
 
+
+    copyRequiresPart(copy : IdlObject) : boolean {
+        // Does the org setting require a part?
+        const copyNode = this.context.findOrCreateCopyNode(copy);
+        const org = copyNode.parentNode.target.owning_lib();
+        const record = copyNode.parentNode.target.record();
+
+        const settingEnabled = this.orgRequiresParts[org];
+        const recordHasParts = this.volcopy.bibParts[record] && this.volcopy.bibParts[record].length > 0;
+
+        const copyStatusHoldable = this.volcopy.copyStatuses[copyNode.target.status()].holdable() === 't';
+        const copyHoldableFlag = copyNode.target.holdable() === 't';
+        const copyShelvingLocationHoldable = copyNode.target.location().holdable() === 't';
+        const copyIsHoldable = copyStatusHoldable && copyHoldableFlag && copyShelvingLocationHoldable;
+
+        const copyRequiresPart = settingEnabled && recordHasParts && copyIsHoldable;
+
+        // Only update when changing in case that matters for performance. (binding propagation)
+        if (this.itemRequirePartsMap[copy.id()] !== copyRequiresPart) {
+            this.itemRequirePartsMap[copy.id()] = copyRequiresPart;
+        }
+
+        return copyRequiresPart;
+
+    }
+
+    partNeeded() : boolean {
+        let needPart = false;
+        let missingCount = 0;
+        for (const copy of this.context.copyList()) {
+            const copyRequiresPart = this.copyRequiresPart(copy);
+
+            const copyHasParts = Boolean(copy.parts()?.length);
+            const copyMissingPart = copyRequiresPart && !copyHasParts;
+            // Visit every copy instead of immediately returning true to update the validity of every copy, not just the first that fails
+            if (copyMissingPart) {
+                needPart = true;
+                missingCount++;
+            }
+
+        }
+        // Silly conditional assignment to not overwhelm Angular change detection
+        if (missingCount !== this.missingPartsCount) {
+            this.missingPartsCount = missingCount;
+        }
+        return needPart;
+    }
+
     @HostListener('window:beforeunload', ['$event'])
     canDeactivate($event?: Event): boolean | Promise<boolean> {
 
