@@ -1,8 +1,7 @@
 import {Component, Input, Output, OnInit, AfterViewInit,
     EventEmitter, ViewChild} from '@angular/core';
 import {ActivatedRoute, ParamMap} from '@angular/router';
-import {Observable, of, from} from 'rxjs';
-import {map, concatMap} from 'rxjs/operators';
+import {Observable, of, from, map, concatMap} from 'rxjs';
 import {IdlObject} from '@eg/core/idl.service';
 import {NetService} from '@eg/core/net.service';
 import {AuthService} from '@eg/core/auth.service';
@@ -67,11 +66,6 @@ export class PatronSearchComponent implements OnInit, AfterViewInit {
     // If set, load a batch of patrons by ID.
     @Input() patronIds: number[];
 
-    // Only allow guaranteed-visible fields to be focused by default.
-    // Options are the DOM ids directly: 'card', 'family_name', 'first_given_name',
-    // 'profile_group', and 'home_ou' (Home Library). Default to 'family_name'.
-    @Input() autofocusField: 'card' | 'family_name' | 'first_given_name' | 'profile_group' | 'home_ou' = 'family_name';
-
     // Fires on dbl-click or Enter while one or more search result
     // rows are selected.
     @Output() patronsActivated: EventEmitter<any>;
@@ -107,6 +101,7 @@ export class PatronSearchComponent implements OnInit, AfterViewInit {
     ) {
         this.patronsActivated = new EventEmitter<any>();
         this.selectionChange = new EventEmitter<number[]>();
+        this.selectionChange = new EventEmitter<number[]>();
         this.searchFired = new EventEmitter<PatronSearch>();
 
         this.dataSource = new GridDataSource();
@@ -141,10 +136,8 @@ export class PatronSearchComponent implements OnInit, AfterViewInit {
     }
 
     ngAfterViewInit() {
-        requestAnimationFrame(() => {
-            const el = document.getElementById(this.autofocusField) as HTMLElement | null;
-            el.focus();
-        });
+        const node = document.getElementById('card');
+        if (node) { node.focus(); }
     }
 
     toggleNameFields() {
