@@ -43,6 +43,7 @@ CREATE TABLE actor.usr (
 	family_name		TEXT				NOT NULL,
 	suffix			TEXT,
     guardian        TEXT,
+    guardian_email        TEXT,
     pref_prefix TEXT,
     pref_first_given_name TEXT,
     pref_second_given_name TEXT,
@@ -159,7 +160,7 @@ CREATE TRIGGER actor_crypt_pw_insert_trigger
 	BEFORE INSERT ON actor.usr FOR EACH ROW
 	EXECUTE PROCEDURE actor.crypt_pw_insert ();
 
-CREATE RULE protect_user_delete AS ON DELETE TO actor.usr DO INSTEAD UPDATE actor.usr SET deleted = TRUE WHERE OLD.id = actor.usr.id;
+CREATE RULE protect_user_delete AS ON DELETE TO actor.usr DO INSTEAD UPDATE actor.usr SET deleted = TRUE WHERE OLD.id = actor.usr.id RETURNING *;
 
 CREATE OR REPLACE FUNCTION actor.user_ingest_name_keywords() 
     RETURNS TRIGGER AS $func$
@@ -192,6 +193,33 @@ CREATE TRIGGER user_ingest_name_keywords_tgr
     BEFORE INSERT OR UPDATE ON actor.usr 
     FOR EACH ROW EXECUTE PROCEDURE actor.user_ingest_name_keywords();
 
+CREATE OR REPLACE FUNCTION evergreen.json_delta(old_obj JSON, new_obj JSON, only_keys TEXT[] DEFAULT '{}') RETURNS JSONB AS $f$
+use JSON;
+use List::Util qw/uniq/;
+
+my $old = shift;
+my $new = shift;
+my $keylist = shift;
+
+$old = from_json($old) if (!ref($old));
+$new = from_json($new) if (!ref($new));
+
+my $delta = {};
+
+my @keys = @$keylist;
+@keys = (keys(%$old), keys(%$new)) if (!@keys);
+
+for my $key (uniq @keys) {
+    $$delta{$key} = [$$old{$key},$$new{$key}] if ((
+        ((!exists($$old{$key}) or !exists($$new{$key})) and not (!exists($$old{$key}) and !exists($$new{$key}))) # one exists
+        or ((!defined($$old{$key}) or !defined($$new{$key})) and not (!defined($$old{$key}) and !defined($$new{$key}))) # or one is defined
+        or ((defined($$old{$key}) and defined($$new{$key})) and $$old{$key} ne $$new{$key}) # or they do not match
+    ) and grep {defined} $$old{$key},$$new{$key}); # there is data
+}
+
+return to_json($delta);
+$f$ LANGUAGE PLPERLU;
+
 CREATE TABLE actor.usr_setting (
 	id	BIGSERIAL	PRIMARY KEY,
 	usr	INT		NOT NULL REFERENCES actor.usr ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED,
@@ -217,6 +245,29 @@ CREATE INDEX actor_usr_setting_phone_values_numeric_idx
     ON actor.usr_setting (evergreen.lowercase(REGEXP_REPLACE(value, '[^0-9]', '', 'g')))
     WHERE name IN ('opac.default_phone', 'opac.default_sms_notify');
 
+-- Start at 100 to avoid barcodes with long stretches of zeros early on.
+-- eCard barcodes have 7 auto-generated digits.
+CREATE SEQUENCE actor.auto_barcode_ecard_seq START 100 MAXVALUE 9999999;
+
+CREATE OR REPLACE FUNCTION actor.generate_barcode
+    (prefix TEXT, numchars INTEGER, seqname TEXT) RETURNS TEXT AS
+$$
+	SELECT NEXTVAL($3); -- bump the sequence up 1
+	SELECT CASE
+		WHEN LENGTH(CURRVAL($3)::TEXT) > $2 THEN NULL
+		ELSE $1 || LPAD(CURRVAL($3)::TEXT, $2, '0')
+		END;
+$$ LANGUAGE SQL;
+
+COMMENT ON FUNCTION actor.generate_barcode(TEXT, INTEGER, TEXT) IS $$
+Generate a barcode starting with 'prefix' and followed by 'numchars'
+numbers.  The auto portion numbers are generated from the provided
+sequence, guaranteeing uniquness across all barcodes generated with
+the same sequence.  The number is left-padded with zeros to meet the
+numchars size requirement.  Returns NULL if the sequnce value is
+higher than numchars can accommodate.
+$$;
+
 CREATE TABLE actor.stat_cat_sip_fields (
     field   CHAR(2) PRIMARY KEY,
     name    TEXT    NOT NULL,
@@ -281,6 +332,38 @@ $$;
 
 CREATE INDEX actor_stat_cat_entry_usr_idx ON actor.stat_cat_entry_usr_map (target_usr);
 
+-- Basically the same thing as using cascade update, but the stat_cat_entry isn't a foreign key as it can be freetext
+CREATE FUNCTION actor.stat_cat_entry_usr_map_cascade_update() RETURNS TRIGGER AS $$
+BEGIN
+    UPDATE actor.stat_cat_entry_usr_map
+    SET stat_cat_entry = NEW.value
+    WHERE stat_cat_entry = OLD.value
+        AND stat_cat = OLD.stat_cat;
+        
+    RETURN NEW;
+END;
+$$ LANGUAGE PLPGSQL;
+
+-- Basically the same thing as using cascade delete, but the stat_cat_entry isn't a foreign key as it can be freetext
+CREATE OR REPLACE FUNCTION actor.stat_cat_entry_usr_map_cascade_delete() RETURNS TRIGGER AS $$
+BEGIN
+    DELETE FROM actor.stat_cat_entry_usr_map
+    WHERE stat_cat_entry = OLD.value
+        AND stat_cat = OLD.stat_cat;
+
+    RETURN NEW;
+END;
+$$ LANGUAGE PLPGSQL;
+
+CREATE TRIGGER actor_stat_cat_entry_update_trigger
+    BEFORE UPDATE ON actor.stat_cat_entry FOR EACH ROW
+    EXECUTE FUNCTION actor.stat_cat_entry_usr_map_cascade_update();
+
+CREATE TRIGGER actor_stat_cat_entry_delete_trigger
+    AFTER DELETE ON actor.stat_cat_entry FOR EACH ROW
+    EXECUTE FUNCTION actor.stat_cat_entry_usr_map_cascade_delete();
+
+
 CREATE FUNCTION actor.stat_cat_check() RETURNS trigger AS $func$
 DECLARE
     sipfield actor.stat_cat_sip_fields%ROWTYPE;
@@ -345,6 +428,7 @@ CREATE TABLE actor.org_unit (
 	email		TEXT,
 	phone		TEXT,
 	opac_visible	BOOL	NOT NULL DEFAULT TRUE,
+    staff_catalog_visible BOOL NOT NULL DEFAULT TRUE,
 	fiscal_calendar INT     NOT NULL DEFAULT 1   -- foreign key constraint to be added later
 );
 CREATE INDEX actor_org_unit_parent_ou_idx ON actor.org_unit (parent_ou);
@@ -395,9 +479,10 @@ CREATE TRIGGER actor_org_unit_parent_protect_trigger
     EXECUTE PROCEDURE actor.org_unit_parent_protect ();
 
 CREATE TABLE actor.org_lasso (
-    id      SERIAL  PRIMARY KEY,
-    name   	TEXT    UNIQUE,
-    global  BOOL    NOT NULL DEFAULT FALSE
+    id            SERIAL  PRIMARY KEY,
+    name   	      TEXT    UNIQUE,
+    global        BOOL    NOT NULL DEFAULT FALSE,
+    opac_visible  BOOL    NOT NULL DEFAULT TRUE
 );
 
 CREATE TABLE actor.org_lasso_map (
@@ -548,6 +633,35 @@ CREATE TABLE actor.workstation (
 	owning_lib	INT	NOT NULL REFERENCES actor.org_unit (id) DEFERRABLE INITIALLY DEFERRED
 );
 
+CREATE TABLE actor.usr_delta_history (
+    id          BIGSERIAL   PRIMARY KEY,
+    eg_user     INT         REFERENCES actor.usr (id) ON UPDATE CASCADE ON DELETE SET NULL,
+    eg_ws       INT         REFERENCES actor.workstation (id) ON UPDATE CASCADE ON DELETE SET NULL,
+    usr_id      INT         NOT NULL REFERENCES actor.usr (id) ON UPDATE CASCADE ON DELETE CASCADE,
+    change_time TIMESTAMPTZ NOT NULL DEFAULT NOW(),
+    delta       JSONB       NOT NULL,
+    keylist     TEXT[]
+);
+
+CREATE OR REPLACE FUNCTION actor.record_usr_delta() RETURNS TRIGGER AS $f$
+BEGIN
+    INSERT INTO actor.usr_delta_history (eg_user, eg_ws, usr_id, delta, keylist)
+        SELECT  a.eg_user,
+                a.eg_ws,
+                OLD.id,
+                evergreen.json_delta(to_json(OLD.*), to_json(NEW.*), TG_ARGV),
+                TG_ARGV
+          FROM  auditor.get_audit_info() a;
+    RETURN NEW;
+END;
+$f$ LANGUAGE PLPGSQL;
+
+CREATE TRIGGER record_usr_delta
+    AFTER UPDATE ON actor.usr
+    FOR EACH ROW
+    EXECUTE FUNCTION actor.record_usr_delta(last_update_time /* unquoted, literal comma-separated column names to include in the delta */);
+ALTER TABLE actor.usr DISABLE TRIGGER record_usr_delta;
+
 CREATE TABLE actor.usr_org_unit_opt_in (
 	id		SERIAL				PRIMARY KEY,
 	org_unit	INT				NOT NULL REFERENCES actor.org_unit (id) DEFERRABLE INITIALLY DEFERRED,
@@ -820,12 +934,7 @@ ALTER TABLE actor.usr_standing_penalty ALTER COLUMN id SET DEFAULT nextval('acto
 ALTER TABLE actor.usr_standing_penalty ADD COLUMN usr_message BIGINT REFERENCES actor.usr_message(id);
 CREATE INDEX usr_standing_penalty_usr_message_idx ON actor.usr_standing_penalty (usr_message);
 
-CREATE RULE protect_usr_message_delete AS
-	ON DELETE TO actor.usr_message DO INSTEAD (
-		UPDATE	actor.usr_message
-		  SET	deleted = TRUE
-		  WHERE	OLD.id = actor.usr_message.id
-	);
+CREATE RULE protect_usr_message_delete AS ON DELETE TO actor.usr_message DO INSTEAD UPDATE actor.usr_message SET deleted = TRUE WHERE OLD.id = actor.usr_message.id RETURNING *;
 
 -- limited view to ensure that a library user who somehow
 -- manages to figure out how to access pcrud cannot change
